@@ -1,21 +1,44 @@
 with_mock_os_release <- function(file, expr) {
-  with_mock(
-    `distro:::have_lsb_release` = function() FALSE, # Make sure we don't call lsb_release
-    `distro:::read_os_release` = function() readLines(test_path(file.path("os-release", file))),
-    eval.parent(expr)
+  with_mocked_bindings(
+    expr,
+    have_lsb_release = function() FALSE, # Make sure we don't call lsb_release
+    read_os_release = function() {
+      readLines(test_path(file.path("os-release", file)))
+    }
   )
 }
 
 test_that("os_release", {
   expect_equal(
-    with_mock_os_release("debian-bullseye", distro()),
+    with_mock_os_release("debian-bookworm-testing", distro()),
     list(
       id = "debian",
       version = NULL,
+      # Codename should be bookworm right?
+      codename = "Debian GNU/Linux bookworm/sid",
+      short_version = "12"
+    )
+  )
+  expect_equal(
+    with_mock_os_release("debian-bullseye-testing", distro()),
+    list(
+      id = "debian",
+      version = NULL,
+      # Codename should be bullseye right?
       codename = "Debian GNU/Linux bullseye/sid",
       short_version = "11"
     )
   )
+  expect_equal(
+    with_mock_os_release("debian-bullseye", distro()),
+    list(
+      id = "debian",
+      version = "11",
+      # Codename should be bullseye right?
+      codename = "bullseye",
+      short_version = "11"
+    )
+  )
   expect_equal(
     with_mock_os_release("ubuntu-xenial", distro()),
     list(
@@ -44,4 +67,3 @@ test_that("os_release", {
     )
   )
 })
-
